@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from django.db import migrations, models
 
 
@@ -13,6 +11,8 @@ class Migration(migrations.Migration):
         migrations.AddField(
             model_name="setting",
             name="validator",
-            field=models.CharField(blank=True, null=True, max_length=255, verbose_name="Validator"),
+            field=models.CharField(
+                blank=True, null=True, max_length=255, verbose_name="Validator"
+            ),
         ),
     ]
