@@ -1,31 +1,19 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import unicode_literals
-
 import importlib
 from decimal import Decimal
 
 import django
-
 from django.conf import settings
 from django.core.exceptions import ValidationError
 from django.db import models
+from django.utils.encoding import force_str
 from jsonfield import JSONField
 
-if django.VERSION < (2, 0):
-    from django.utils.encoding import force_text as force_str
-else:
-    from django.utils.encoding import force_str
-
-from six import python_2_unicode_compatible
-
 from extra_settings import fields
 from extra_settings.cache import get_cached_setting, set_cached_setting
 from extra_settings.translation import gettext_lazy as _
 from extra_settings.utils import enforce_uppercase_setting, import_function
 
 
-@python_2_unicode_compatible
 class Setting(models.Model):
     """
     This class describes a Setting model.
@@ -151,7 +139,7 @@ class Setting(models.Model):
     )
 
     name = models.CharField(
-        max_length=50,
+        max_length=255,
         unique=True,
         verbose_name=_("Name"),
         help_text="(e.g. SETTING_NAME)",
@@ -186,7 +174,7 @@ class Setting(models.Model):
     )
     value_int = models.IntegerField(blank=True, default=0, verbose_name=_("Value"))
     value_json = JSONField(blank=True, default=dict, verbose_name=_("Value"))
-    value_string = models.CharField(blank=True, max_length=50, verbose_name=_("Value"))
+    value_string = models.CharField(blank=True, max_length=255, verbose_name=_("Value"))
     value_text = models.TextField(blank=True, verbose_name=_("Value"))
     value_time = models.TimeField(blank=True, null=True, verbose_name=_("Value"))
     value_url = models.URLField(blank=True, verbose_name=_("Value"))
@@ -203,7 +191,7 @@ class Setting(models.Model):
 
     @property
     def value_field_name(self):
-        return "{}_{}".format("value", self.value_type)
+        return f"value_{self.value_type}"
 
     @property
     def value(self):
@@ -225,15 +213,12 @@ class Setting(models.Model):
             return
         validator_func = import_function(self.validator)
         if not validator_func:
-            raise ValueError(
-                "Invalid validator function path: '{}'".format(self.validator)
-            )
+            raise ValueError(f"Invalid validator function path: '{self.validator}'")
         is_valid = validator_func(self.value)
         if not is_valid:
             raise ValidationError(
-                "Invalid value for setting '{}', {} could not be validated by '{}' validator.".format(
-                    self.name, self.value, self.validator
-                )
+                f"Invalid value for setting '{self.name}', "
+                f"{self.value} is not validated by '{self.validator}' validator."
             )
 
     def save(self, *args, **kwargs):
@@ -251,4 +236,4 @@ class Setting(models.Model):
         verbose_name_plural = _("Settings")
 
     def __str__(self):
-        return force_str("{} [{}]".format(self.name, self.value_type))
+        return force_str(f"{self.name} [{self.value_type}]")
