@@ -1,7 +1,3 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import unicode_literals
-
 from django.utils.module_loading import import_string
 from django.utils.text import slugify
 
